
# Slot: is missense variant of


holds between a gene  and a sequence variant, such the sequence variant results in a different amino acid sequence but where the length is preserved.

URI: [biolink:is_missense_variant_of](https://w3id.org/biolink/vocab/is_missense_variant_of)


## Domain and Range

[SequenceVariant](SequenceVariant.md) &#8594;  <sub>0..\*</sub> [Gene](Gene.md)

## Parents

 *  is_a: [is sequence variant of](is_sequence_variant_of.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | SO:0001583 |
|  | | SNPEFF:missense_variant |
| **Narrow Mappings:** | | SNPEFF:initiator_codon_variant |
|  | | SNPEFF:structural_interaction_variant |

